==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/fr_fr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.category_added'] = 'La catégorie a été créée avec succès.';
$lang['AdminMain.!success.category_updated'] = 'La catégorie a été mise à jour avec succès.';
$lang['AdminMain.!success.category_deleted'] = 'La catégorie a été supprimée avec succès.';
$lang['AdminMain.!success.file_added'] = 'Le fichier a été ajouté avec succès.';
$lang['AdminMain.!success.file_updated'] = 'Le fichier a été mis à jour avec succès.';
$lang['AdminMain.!success.file_deleted'] = 'Le fichier a été supprimé avec succès.';
$lang['AdminMain.!success.url_deleted'] = 'L\'URL statique a été supprimée avec succès.';
$lang['AdminMain.!success.url_added'] = 'L\'URL statique a été ajoutée avec succès.';
$lang['AdminMain.!success.url_updated'] = 'L\'URL statique a été mise à jour avec succès.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Saisissez le chemin d\'accès absolu au fichier sur le système de fichiers.';
$lang['AdminMain.!tooltip.category_type'] = 'L\'URL pointera vers le dernier fichier téléchargé dans cette catégorie.';
$lang['AdminMain.!text.root_directory'] = 'Répertoire d\'accueil';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.modal.delete_file'] = 'Êtes-vous sûr de vouloir supprimer ce fichier ?';
$lang['AdminMain.modal.delete_category'] = 'Êtes-vous sûr de vouloir supprimer cette catégorie ? Toutes les sous-catégories et tous les fichiers de cette catégorie seront déplacés vers la catégorie mère.';
$lang['AdminMain.modal.delete_url'] = 'Êtes-vous sûr de vouloir supprimer cette URL statique ?';
$lang['AdminMain.files.page_title'] = 'Download Manager > Gérer';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Gestionnaire de téléchargement';
$lang['AdminMain.files.tab_files'] = 'Dossiers';
$lang['AdminMain.files.tab_urls'] = 'URL statiques';
$lang['AdminMain.files.add_download'] = 'Ajouter le téléchargement ici';
$lang['AdminMain.files.add_category'] = 'Ajouter une catégorie ici';
$lang['AdminMain.files.go_back'] = 'Monter d\'un niveau';
$lang['AdminMain.files.edit'] = 'Editer';
$lang['AdminMain.files.delete'] = 'Supprimer';
$lang['AdminMain.files.no_downloads'] = 'Il n\'y a pas de téléchargements dans cette section.';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Gérer';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Gestionnaire de téléchargement';
$lang['AdminMain.urls.add_url'] = 'Ajouter une URL statique';
$lang['AdminMain.urls.tab_files'] = 'Dossiers';
$lang['AdminMain.urls.tab_urls'] = 'URL statiques';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.heading_file'] = 'Fichier';
$lang['AdminMain.urls.heading_link'] = 'Lien';
$lang['AdminMain.urls.heading_options'] = 'Options';
$lang['AdminMain.urls.edit'] = 'Editer';
$lang['AdminMain.urls.delete'] = 'Supprimer';
$lang['AdminMain.urls.latest_file'] = 'Dernier fichier de <strong>%1$s</strong>';
$lang['AdminMain.urls.no_urls'] = 'Il n\'y a pas d\'URL statiques dans cette section.';
$lang['AdminMain.add.page_title'] = 'Gestionnaire de téléchargement > Ajouter un téléchargement';
$lang['AdminMain.add.boxtitle_root'] = 'Ajouter le téléchargement au %1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Ajouter le téléchargement à la catégorie [%1$s]';
$lang['AdminMain.add.field_public'] = 'Disponible au public';
$lang['AdminMain.add.field_logged_in'] = 'Vous devez être connecté';
$lang['AdminMain.add.field_name'] = 'Nom';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Disponible pour les groupes de clients';
$lang['AdminMain.add.field_available_to_packages'] = 'Disponible pour les paquets';
$lang['AdminMain.add.text_clientgroups'] = 'Groupes de clients sélectionnés';
$lang['AdminMain.add.text_packagegroups'] = 'Paquets sélectionnés';
$lang['AdminMain.add.text_availableclientgroups'] = 'Groupes de clients disponibles';
$lang['AdminMain.add.text_availablepackages'] = 'Packages disponibles';
$lang['AdminMain.add.field_upload'] = 'Télécharger le fichier';
$lang['AdminMain.add.field_path'] = 'Spécifier le chemin d\'accès au fichier';
$lang['AdminMain.add.field_file'] = 'Fichier';
$lang['AdminMain.add.field_file_name'] = 'Chemin d\'accès au fichier';
$lang['AdminMain.add.submit_add'] = 'Ajouter un téléchargement';
$lang['AdminMain.add.submit_cancel'] = 'Annuler';
$lang['AdminMain.addurl.page_title'] = 'Gestionnaire de téléchargement > Ajouter une URL statique';
$lang['AdminMain.addurl.boxtitle_add'] = 'Ajouter une URL statique';
$lang['AdminMain.addurl.field_url'] = 'Nom de l\'URL';
$lang['AdminMain.addurl.field_file'] = 'Fichier';
$lang['AdminMain.addurl.field_category'] = 'Catégorie';
$lang['AdminMain.addurl.submit_add'] = 'Ajouter une URL';
$lang['AdminMain.addurl.submit_cancel'] = 'Annuler';
$lang['AdminMain.edit.page_title'] = 'Gestionnaire de téléchargement > Ajouter un téléchargement';
$lang['AdminMain.edit.boxtitle_edit'] = 'Téléchargement de la mise à jour';
$lang['AdminMain.edit.field_public'] = 'Disponible au public';
$lang['AdminMain.edit.field_logged_in'] = 'Vous devez être connecté';
$lang['AdminMain.edit.field_name'] = 'Nom';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Disponible pour les groupes de clients';
$lang['AdminMain.edit.field_available_to_packages'] = 'Disponible pour les paquets';
$lang['AdminMain.edit.text_clientgroups'] = 'Groupes de clients sélectionnés';
$lang['AdminMain.edit.text_packagegroups'] = 'Paquets sélectionnés';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Groupes de clients disponibles';
$lang['AdminMain.edit.text_availablepackages'] = 'Packages disponibles';
$lang['AdminMain.edit.field_upload'] = 'Télécharger le fichier';
$lang['AdminMain.edit.field_path'] = 'Spécifier le chemin d\'accès au fichier';
$lang['AdminMain.edit.field_file'] = 'Fichier';
$lang['AdminMain.edit.field_file_name'] = 'Chemin d\'accès au fichier';
$lang['AdminMain.edit.submit_edit'] = 'Téléchargement de la mise à jour';
$lang['AdminMain.edit.submit_cancel'] = 'Annuler';
$lang['AdminMain.editurl.page_title'] = 'Gestionnaire de téléchargement > Modifier l\'URL statique';
$lang['AdminMain.editurl.boxtitle_add'] = 'Modifier l\'URL statique';
$lang['AdminMain.editurl.field_url'] = 'Nom de l\'URL';
$lang['AdminMain.editurl.field_file'] = 'Fichier';
$lang['AdminMain.editurl.field_category'] = 'Catégorie';
$lang['AdminMain.editurl.submit_add'] = 'Modifier l\'URL';
$lang['AdminMain.editurl.submit_cancel'] = 'Annuler';
$lang['AdminMain.addcategory.page_title'] = 'Gestionnaire de téléchargement > Ajouter une catégorie';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Ajouter une catégorie au %1$s';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Ajouter une catégorie à la catégorie [%1$s]';
$lang['AdminMain.addcategory.field_name'] = 'Nom';
$lang['AdminMain.addcategory.field_description'] = 'Description';
$lang['AdminMain.addcategory.submit_add'] = 'Créer une catégorie';
$lang['AdminMain.addcategory.submit_cancel'] = 'Annuler';
$lang['AdminMain.editcategory.page_title'] = 'Gestionnaire de téléchargement > Catégorie de mise à jour';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Mise à jour de la catégorie [%1$s]';
$lang['AdminMain.editcategory.field_name'] = 'Nom';
$lang['AdminMain.editcategory.field_description'] = 'Description';
$lang['AdminMain.editcategory.submit_edit'] = 'Catégorie de mise à jour';
$lang['AdminMain.editcategory.submit_cancel'] = 'Annuler';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/fr_fr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.category_added'] = 'La catégorie a été créée avec succès.';
$lang['AdminMain.!success.category_updated'] = 'La catégorie a été mise à jour avec succès.';
$lang['AdminMain.!success.category_deleted'] = 'La catégorie a été supprimée avec succès.';
$lang['AdminMain.!success.file_added'] = 'Le fichier a été ajouté avec succès.';
$lang['AdminMain.!success.file_updated'] = 'Le fichier a été mis à jour avec succès.';
$lang['AdminMain.!success.file_deleted'] = 'Le fichier a été supprimé avec succès.';
$lang['AdminMain.!success.url_deleted'] = 'L\'URL statique a été supprimée avec succès.';
$lang['AdminMain.!success.url_added'] = 'L\'URL statique a été ajoutée avec succès.';
$lang['AdminMain.!success.url_updated'] = 'L\'URL statique a été mise à jour avec succès.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Saisissez le chemin d\'accès absolu au fichier sur le système de fichiers.';
$lang['AdminMain.!tooltip.category_type'] = 'L\'URL pointera vers le dernier fichier téléchargé dans cette catégorie.';
$lang['AdminMain.!text.root_directory'] = 'Répertoire d\'accueil';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.modal.delete_file'] = 'Êtes-vous sûr de vouloir supprimer ce fichier ?';
$lang['AdminMain.modal.delete_category'] = 'Êtes-vous sûr de vouloir supprimer cette catégorie ? Toutes les sous-catégories et tous les fichiers de cette catégorie seront déplacés vers la catégorie mère.';
$lang['AdminMain.modal.delete_url'] = 'Êtes-vous sûr de vouloir supprimer cette URL statique ?';
$lang['AdminMain.files.page_title'] = 'Download Manager > Gérer';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Gestionnaire de téléchargement';
$lang['AdminMain.files.tab_files'] = 'Dossiers';
$lang['AdminMain.files.tab_urls'] = 'URL statiques';
$lang['AdminMain.files.add_download'] = 'Ajouter le téléchargement ici';
$lang['AdminMain.files.add_category'] = 'Ajouter une catégorie ici';
$lang['AdminMain.files.go_back'] = 'Monter d\'un niveau';
$lang['AdminMain.files.edit'] = 'Editer';
$lang['AdminMain.files.delete'] = 'Supprimer';
$lang['AdminMain.files.no_downloads'] = 'Il n\'y a pas de téléchargements dans cette section.';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Gérer';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Gestionnaire de téléchargement';
$lang['AdminMain.urls.add_url'] = 'Ajouter une URL statique';
$lang['AdminMain.urls.tab_files'] = 'Dossiers';
$lang['AdminMain.urls.tab_urls'] = 'URL statiques';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.heading_file'] = 'Fichier';
$lang['AdminMain.urls.heading_link'] = 'Lien';
$lang['AdminMain.urls.heading_options'] = 'Options';
$lang['AdminMain.urls.edit'] = 'Editer';
$lang['AdminMain.urls.delete'] = 'Supprimer';
$lang['AdminMain.urls.latest_file'] = 'Dernier fichier de <strong>%1$s</strong>';
$lang['AdminMain.urls.no_urls'] = 'Il n\'y a pas d\'URL statiques dans cette section.';
$lang['AdminMain.add.page_title'] = 'Gestionnaire de téléchargement > Ajouter un téléchargement';
$lang['AdminMain.add.boxtitle_root'] = 'Ajouter le téléchargement au %1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Ajouter le téléchargement à la catégorie [%1$s]';
$lang['AdminMain.add.field_public'] = 'Disponible au public';
$lang['AdminMain.add.field_logged_in'] = 'Vous devez être connecté';
$lang['AdminMain.add.field_name'] = 'Nom';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Disponible pour les groupes de clients';
$lang['AdminMain.add.field_available_to_packages'] = 'Disponible pour les paquets';
$lang['AdminMain.add.text_clientgroups'] = 'Groupes de clients sélectionnés';
$lang['AdminMain.add.text_packagegroups'] = 'Paquets sélectionnés';
$lang['AdminMain.add.text_availableclientgroups'] = 'Groupes de clients disponibles';
$lang['AdminMain.add.text_availablepackages'] = 'Packages disponibles';
$lang['AdminMain.add.field_upload'] = 'Télécharger le fichier';
$lang['AdminMain.add.field_path'] = 'Spécifier le chemin d\'accès au fichier';
$lang['AdminMain.add.field_file'] = 'Fichier';
$lang['AdminMain.add.field_file_name'] = 'Chemin d\'accès au fichier';
$lang['AdminMain.add.submit_add'] = 'Ajouter un téléchargement';
$lang['AdminMain.add.submit_cancel'] = 'Annuler';
$lang['AdminMain.addurl.page_title'] = 'Gestionnaire de téléchargement > Ajouter une URL statique';
$lang['AdminMain.addurl.boxtitle_add'] = 'Ajouter une URL statique';
$lang['AdminMain.addurl.field_url'] = 'Nom de l\'URL';
$lang['AdminMain.addurl.field_file'] = 'Fichier';
$lang['AdminMain.addurl.field_category'] = 'Catégorie';
$lang['AdminMain.addurl.submit_add'] = 'Ajouter une URL';
$lang['AdminMain.addurl.submit_cancel'] = 'Annuler';
$lang['AdminMain.edit.page_title'] = 'Gestionnaire de téléchargement > Ajouter un téléchargement';
$lang['AdminMain.edit.boxtitle_edit'] = 'Téléchargement de la mise à jour';
$lang['AdminMain.edit.field_public'] = 'Disponible au public';
$lang['AdminMain.edit.field_logged_in'] = 'Vous devez être connecté';
$lang['AdminMain.edit.field_name'] = 'Nom';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Disponible pour les groupes de clients';
$lang['AdminMain.edit.field_available_to_packages'] = 'Disponible pour les paquets';
$lang['AdminMain.edit.text_clientgroups'] = 'Groupes de clients sélectionnés';
$lang['AdminMain.edit.text_packagegroups'] = 'Paquets sélectionnés';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Groupes de clients disponibles';
$lang['AdminMain.edit.text_availablepackages'] = 'Packages disponibles';
$lang['AdminMain.edit.field_upload'] = 'Télécharger le fichier';
$lang['AdminMain.edit.field_path'] = 'Spécifier le chemin d\'accès au fichier';
$lang['AdminMain.edit.field_file'] = 'Fichier';
$lang['AdminMain.edit.field_file_name'] = 'Chemin d\'accès au fichier';
$lang['AdminMain.edit.submit_edit'] = 'Téléchargement de la mise à jour';
$lang['AdminMain.edit.submit_cancel'] = 'Annuler';
$lang['AdminMain.editurl.page_title'] = 'Gestionnaire de téléchargement > Modifier l\'URL statique';
$lang['AdminMain.editurl.boxtitle_add'] = 'Modifier l\'URL statique';
$lang['AdminMain.editurl.field_url'] = 'Nom de l\'URL';
$lang['AdminMain.editurl.field_file'] = 'Fichier';
$lang['AdminMain.editurl.field_category'] = 'Catégorie';
$lang['AdminMain.editurl.submit_add'] = 'Modifier l\'URL';
$lang['AdminMain.editurl.submit_cancel'] = 'Annuler';
$lang['AdminMain.addcategory.page_title'] = 'Gestionnaire de téléchargement > Ajouter une catégorie';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Ajouter une catégorie au %1$s';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Ajouter une catégorie à la catégorie [%1$s]';
$lang['AdminMain.addcategory.field_name'] = 'Nom';
$lang['AdminMain.addcategory.field_description'] = 'Description';
$lang['AdminMain.addcategory.submit_add'] = 'Créer une catégorie';
$lang['AdminMain.addcategory.submit_cancel'] = 'Annuler';
$lang['AdminMain.editcategory.page_title'] = 'Gestionnaire de téléchargement > Catégorie de mise à jour';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Mise à jour de la catégorie [%1$s]';
$lang['AdminMain.editcategory.field_name'] = 'Nom';
$lang['AdminMain.editcategory.field_description'] = 'Description';
$lang['AdminMain.editcategory.submit_edit'] = 'Catégorie de mise à jour';
$lang['AdminMain.editcategory.submit_cancel'] = 'Annuler';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.edit.text_full_path'] = 'REMARQUE : les fichiers doivent se trouver dans votre répertoire de téléchargement : <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = 'REMARQUE : les fichiers doivent se trouver dans votre répertoire de téléchargement : <strong>%1$s</strong>.';
